@@ -309,8 +309,10 @@ void StatusNotifierItemSource::refreshCallback(QDBusPendingCallWatcher *call)
         }
 
         auto loadIcon = [this, &properties, &overlay](const QString &iconKey, const QString &pixmapKey) -> std::tuple<QIcon, QString> {
-            const QString iconName = properties[iconKey].toString();
-            if (!iconName.isEmpty()) {
+            if (QString iconName = properties[iconKey].toString(); !iconName.isEmpty()) {
+                if (!QDir::isAbsolutePath(iconName) && iconLoader()->hasIcon(iconName + QStringLiteral("-symbolic"))) {
+                    iconName += QStringLiteral("-symbolic");
+                }
                 QIcon icon = QIcon(new KIconEngine(iconName, KIconColors(Plasma::Theme::globalPalette()), iconLoader(), {m_overlayIconName}));
                 if (!icon.isNull()) {
                     if (!overlay.isNull() && m_overlayIconName.isEmpty()) {
@@ -534,3 +536,5 @@ void StatusNotifierItemSource::provideXdgActivationToken(const QString &token)
         m_statusNotifierItemInterface->ProvideXdgActivationToken(token);
     }
 }
+
+#include "moc_statusnotifieritemsource.cpp"
