@@ -16,7 +16,6 @@
 #include <KConfig>
 #include <KConfigGroup>
 #include <KConfigLoader>
-#include <KConfigPropertyMap>
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <plasmaactivities/consumer.h>
@@ -59,7 +58,7 @@ const QDBusArgument &operator>>(const QDBusArgument &argument, QColor &color)
 
 WallpaperModule::~WallpaperModule()
 {
-    disconnect(m_wallpaperConfiguration, &QQmlPropertyMap::valueChanged, this, nullptr);
+    disconnect(m_wallpaperConfiguration.get(), &QQmlPropertyMap::valueChanged, this, nullptr);
 }
 
 WallpaperModule::WallpaperModule(QObject *parent, const KPluginMetaData &data)
@@ -104,15 +103,7 @@ WallpaperModule::WallpaperModule(QObject *parent, const KPluginMetaData &data)
             Qt::ConnectionType::SingleShotConnection);
     });
 
-    const bool connected = QDBusConnection::sessionBus().connect(QStringLiteral("org.kde.plasmashell"),
-                                                                 QStringLiteral("/PlasmaShell"),
-                                                                 QStringLiteral("org.kde.PlasmaShell"),
-                                                                 QStringLiteral("wallpaperChanged"),
-                                                                 this,
-                                                                 SLOT(onWallpaperChanged(uint)));
-    if (!connected) {
-        qCFatal(KCM_WALLPAPER_DEBUG) << "Could not connect to dbus service org.kde.plasmashell";
-    }
+    connectToPlasmaShell();
 
     setButtons(Apply | Default);
 
@@ -127,6 +118,29 @@ WallpaperModule::WallpaperModule(QObject *parent, const KPluginMetaData &data)
     });
 }
 
+void WallpaperModule::connectToPlasmaShell()
+{
+    const bool connected = QDBusConnection::sessionBus().connect(QStringLiteral("org.kde.plasmashell"),
+                                                                 QStringLiteral("/PlasmaShell"),
+                                                                 QStringLiteral("org.kde.PlasmaShell"),
+                                                                 QStringLiteral("wallpaperChanged"),
+                                                                 this,
+                                                                 SLOT(onWallpaperChanged(uint)));
+    if (!connected) {
+        qCFatal(KCM_WALLPAPER_DEBUG) << "Could not connect to dbus service org.kde.plasmashell";
+    }
+}
+
+void WallpaperModule::disconnectFromPlasmaShell()
+{
+    QDBusConnection::sessionBus().disconnect(QStringLiteral("org.kde.plasmashell"),
+                                             QStringLiteral("/PlasmaShell"),
+                                             QStringLiteral("org.kde.PlasmaShell"),
+                                             QStringLiteral("wallpaperChanged"),
+                                             this,
+                                             SLOT(onWallpaperChanged(uint)));
+}
+
 void WallpaperModule::onScreenChanged()
 {
     if (m_activityId.isEmpty() || m_activityId == QUuid().toString()) {
@@ -167,7 +181,6 @@ void WallpaperModule::onScreenChanged()
     auto containmentConfigGroup = containmentsGroup.group(m_containmentIdx);
     m_loadedWallpaperplugin = containmentConfigGroup.readEntry("wallpaperplugin");
 
-    auto previousConfig = m_wallpaperConfiguration;
     setWallpaperPluginConfiguration(m_loadedWallpaperplugin);
 
     setRepresentsDefaults(isDefault());
@@ -179,8 +192,6 @@ void WallpaperModule::onScreenChanged()
     } else {
         Q_EMIT wallpaperConfigurationChanged();
     }
-
-    delete previousConfig;
 }
 
 int WallpaperModule::screenIdFromName(const QString &screenName) const
@@ -201,6 +212,9 @@ int WallpaperModule::screenIdFromName(const QString &screenName) const
 
 void WallpaperModule::setWallpaperPluginConfiguration(const QString &wallpaperplugin, bool loadDefaults)
 {
+    // avoid recursive updating state
+    disconnectFromPlasmaShell();
+
     auto wallpaperConfig = m_config->group(QStringLiteral("Containments")).group(m_containmentIdx).group(QStringLiteral("Wallpaper")).group(wallpaperplugin);
     m_wallpaperConfigGeneral = wallpaperConfig.group(QStringLiteral("General"));
 
@@ -213,7 +227,7 @@ void WallpaperModule::setWallpaperPluginConfiguration(const QString &wallpaperpl
     if (loadDefaults) {
         m_configLoader->setDefaults();
     }
-    m_wallpaperConfiguration = new KConfigPropertyMap(m_configLoader, this);
+    m_wallpaperConfiguration.reset(new KConfigPropertyMap(m_configLoader, this));
 
     // set the default wallpaper value
     m_defaultWallpaper = DefaultWallpaper::defaultWallpaperPackage().path();
@@ -224,10 +238,12 @@ void WallpaperModule::setWallpaperPluginConfiguration(const QString &wallpaperpl
         m_wallpaperConfiguration->insert(QStringLiteral("Image"), m_defaultWallpaper);
     }
 
-    connect(m_wallpaperConfiguration, &QQmlPropertyMap::valueChanged, this, [this](const QString & /* key */, const QVariant & /* value */) {
+    connect(m_wallpaperConfiguration.get(), &QQmlPropertyMap::valueChanged, this, [this](const QString & /* key */, const QVariant & /* value */) {
         setRepresentsDefaults(isDefault());
         setNeedsSave(m_configLoader->isSaveNeeded() || m_loadedWallpaperplugin != m_currentWallpaperPlugin);
     });
+
+    connectToPlasmaShell();
 }
 
 class WallpaperConfigModel : public PlasmaQuick::ConfigModel
@@ -287,9 +303,6 @@ void WallpaperModule::defaults()
         Q_EMIT currentWallpaperPluginChanged();
     }
 
-    auto previousConfig = m_wallpaperConfiguration;
-    disconnect(previousConfig, nullptr);
-
     setWallpaperPluginConfiguration(m_currentWallpaperPlugin, true);
     m_wallpaperConfiguration->insert(QStringLiteral("Image"), m_defaultWallpaper);
 
@@ -297,8 +310,6 @@ void WallpaperModule::defaults()
     setNeedsSave(m_configLoader->isSaveNeeded() || m_loadedWallpaperplugin != m_currentWallpaperPlugin);
 
     Q_EMIT wallpaperConfigurationChanged();
-
-    delete previousConfig;
 }
 
 void WallpaperModule::load()
@@ -319,11 +330,9 @@ void WallpaperModule::save()
     QList<uint> screenIds;
 
     if (m_allScreens) {
-        uint idx = 0;
         const auto outputOrder = m_outputOrderWatcher->outputOrder();
-        for (const auto &output : outputOrder) {
+        for (uint idx = 0; idx < outputOrder.size(); ++idx) {
             screenIds.append(idx);
-            ++idx;
         }
     } else {
         int screenId = screenIdFromName(m_selectedScreen->name());
@@ -359,7 +368,7 @@ void WallpaperModule::save()
 
 QQmlPropertyMap *WallpaperModule::wallpaperConfiguration() const
 {
-    return m_wallpaperConfiguration;
+    return m_wallpaperConfiguration.get();
 }
 
 QString WallpaperModule::currentWallpaperPlugin() const
@@ -429,16 +438,12 @@ void WallpaperModule::setCurrentWallpaperPlugin(const QString &wallpaperPlugin)
     }
 
     m_currentWallpaperPlugin = wallpaperPlugin;
-    auto previousConfig = m_wallpaperConfiguration;
-    disconnect(previousConfig, nullptr);
 
     setWallpaperPluginConfiguration(m_currentWallpaperPlugin);
 
     setNeedsSave(needsSave() || m_loadedWallpaperplugin != m_currentWallpaperPlugin);
 
     Q_EMIT currentWallpaperPluginChanged();
-
-    delete previousConfig;
 }
 
 PlasmaQuick::ConfigModel *WallpaperModule::wallpaperConfigModel()
@@ -486,3 +491,5 @@ void WallpaperConfigModel::repopulate()
 }
 
 #include "wallpapermodule.moc"
+
+#include "moc_wallpapermodule.cpp"
