@@ -19,6 +19,7 @@
 #include <QLabel>
 #include <QMenu>
 #include <QMessageBox>
+#include <QMimeData>
 #include <QPushButton>
 #include <QResizeEvent>
 
@@ -36,12 +37,10 @@
 #include <KWayland/Client/surface.h>
 #include <KWindowSystem>
 
-#include "../c_ptr.h"
 #include "configdialog.h"
 #include "historycycler.h"
 #include "historyitem.h"
 #include "historymodel.h"
-#include "historystringitem.h"
 #include "klipperpopup.h"
 #include "klippersettings.h"
 #include "systemclipboard.h"
@@ -58,7 +57,7 @@ std::shared_ptr<Klipper> Klipper::self()
 {
     static std::weak_ptr<Klipper> s_instance;
     if (s_instance.expired()) {
-        std::shared_ptr<Klipper> ptr = std::make_shared<Klipper>(nullptr, KSharedConfig::openConfig(QStringLiteral("klipperrc")));
+        std::shared_ptr<Klipper> ptr = std::make_shared<Klipper>(nullptr);
         s_instance = ptr;
         return ptr;
     }
@@ -66,12 +65,11 @@ std::shared_ptr<Klipper> Klipper::self()
 }
 
 // config == KGlobal::config for process, otherwise applet
-Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config)
+Klipper::Klipper(QObject *parent)
     : QObject(parent)
     , m_clip(SystemClipboard::self())
     , m_historyCycler(new HistoryCycler(this))
     , m_quitAction(nullptr)
-    , m_config(config)
     , m_plasmashell(nullptr)
 {
     QDBusConnection::sessionBus().registerService(QStringLiteral("org.kde.klipper"));
@@ -79,9 +77,6 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config)
                                                  this,
                                                  QDBusConnection::ExportScriptableSlots | QDBusConnection::ExportScriptableSignals);
 
-    connect(m_clip.get(), &SystemClipboard::ignored, this, &Klipper::slotIgnored);
-    connect(m_clip.get(), &SystemClipboard::newClipData, this, &Klipper::checkClipData);
-
     m_historyModel = HistoryModel::self();
     m_popup = std::make_unique<KlipperPopup>();
     connect(m_historyModel.get(), &HistoryModel::changed, this, &Klipper::slotHistoryChanged);
@@ -124,7 +119,7 @@ Klipper::Klipper(QObject *parent, const KSharedConfigPtr &config)
     m_repeatAction = m_collection->addAction(QStringLiteral("repeat_action"));
     m_repeatAction->setText(i18nc("@action:inmenu", "Manually Invoke Action on Current Clipboard"));
     m_repeatAction->setIcon(QIcon::fromTheme(QStringLiteral("open-menu-symbolic")));
-    KGlobalAccel::setGlobalShortcut(m_repeatAction, QKeySequence(Qt::META | Qt::CTRL | Qt::Key_R));
+    KGlobalAccel::setGlobalShortcut(m_repeatAction, QKeySequence());
     connect(m_repeatAction, &QAction::triggered, this, &Klipper::slotRepeatAction);
 
     // add barcode for mobile phones
@@ -204,15 +199,28 @@ void Klipper::showKlipperManuallyInvokeActionMenu()
     slotRepeatAction();
 }
 
+void Klipper::reloadConfig()
+{
+    if (calledFromDBus()) {
+        KlipperSettings::self()->sharedConfig()->reparseConfiguration();
+        KlipperSettings::self()->read();
+    }
+    loadSettings();
+    // BUG: 142882
+    // Security: If user has save clipboard turned off, old data should be deleted from disk
+    if (!m_bKeepContents) {
+        m_historyModel->clear();
+    }
+}
+
 // DBUS - don't call from Klipper itself
 void Klipper::setClipboardContents(const QString &s)
 {
     if (s.isEmpty())
         return;
     updateTimestamp();
-    HistoryItemPtr item(HistoryItemPtr(new HistoryStringItem(s)));
-    m_clip->setMimeData(item, SystemClipboard::SelectionMode(SystemClipboard::Clipboard | SystemClipboard::Selection));
-    m_historyModel->insert(item);
+    m_historyModel->insert(s);
+    m_clip->setMimeData(m_historyModel->first(), SystemClipboard::SelectionMode(SystemClipboard::Clipboard | SystemClipboard::Selection));
 }
 
 // DBUS - don't call from Klipper itself
@@ -230,10 +238,9 @@ void Klipper::clearClipboardHistory()
     saveSession();
 }
 
-// DBUS - don't call from Klipper itself
 void Klipper::saveClipboardHistory()
 {
-    m_historyModel->saveHistory();
+    m_historyModel->saveClipboardHistory();
 }
 
 void Klipper::slotStartShowTimer()
@@ -245,19 +252,8 @@ void Klipper::loadSettings()
 {
     m_bKeepContents = KlipperSettings::keepClipboardContents();
     m_bReplayActionInHistory = KlipperSettings::replayActionInHistory();
-    m_bNoNullClipboard = KlipperSettings::preventEmptyClipboard();
-    if (m_bNoNullClipboard) {
-        connect(m_clip.get(), &SystemClipboard::receivedEmptyClipboard, this, &Klipper::slotReceivedEmptyClipboard, Qt::UniqueConnection);
-    } else {
-        disconnect(m_clip.get(), &SystemClipboard::receivedEmptyClipboard, this, &Klipper::slotReceivedEmptyClipboard);
-    }
-    // 0 is the id of "Ignore selection" radiobutton
-    m_bIgnoreSelection = KlipperSettings::ignoreSelection();
-    m_bIgnoreImages = KlipperSettings::ignoreImages();
-    m_bSynchronize = KlipperSettings::syncClipboards();
     // NOTE: not used atm - kregexpeditor is not ported to kde4
     m_bUseGUIRegExpEditor = KlipperSettings::useGUIRegExpEditor();
-    m_bSelectionTextOnly = KlipperSettings::selectionTextOnly();
 
     m_bURLGrabber = KlipperSettings::uRLGrabberEnabled();
     // this will cause it to loadSettings too
@@ -306,7 +302,6 @@ bool Klipper::eventFilter(QObject *filtered, QEvent *event)
 // save session on shutdown. Don't simply use the c'tor, as that may not be called.
 void Klipper::saveSession()
 {
-    m_historyModel->saveHistory();
     saveSettings();
 }
 
@@ -339,43 +334,10 @@ void Klipper::slotConfigure()
     // Klipper settings every time that it is shown.
     dlg->setAttribute(Qt::WA_DeleteOnClose);
 
-    connect(dlg, &KConfigDialog::settingsChanged, this, [this]() {
-        const bool bKeepContents_old = m_bKeepContents; // back up old value
-        loadSettings();
-
-        // BUG: 142882
-        // Security: If user has save clipboard turned off, old data should be deleted from disk
-        if (bKeepContents_old != m_bKeepContents) { // keepContents changed
-            m_historyModel->saveHistory(!m_bKeepContents); // save history, empty = !keep
-        }
-    });
+    connect(dlg, &KConfigDialog::settingsChanged, this, &Klipper::reloadConfig);
     dlg->show();
 }
 
-void Klipper::slotIgnored(QClipboard::Mode mode)
-{
-    // internal to klipper, ignoring QSpinBox selections
-    // keep our old clipboard, thanks
-    // This won't quite work, but it's close enough for now.
-    // The trouble is that the top selection =! top clipboard
-    // but we don't track that yet. We will....
-    if (auto top = m_historyModel->first()) {
-        m_clip->setMimeData(top, mode == QClipboard::Selection ? SystemClipboard::Selection : SystemClipboard::Clipboard);
-    }
-}
-
-void Klipper::slotReceivedEmptyClipboard(QClipboard::Mode mode)
-{
-    Q_ASSERT(m_bNoNullClipboard);
-    if (auto top = m_historyModel->first()) {
-        // keep old clipboard after someone set it to null
-        qCDebug(KLIPPER_LOG) << "Resetting clipboard (Prevent empty clipboard)";
-        m_clip->setMimeData(top,
-                            mode == QClipboard::Selection ? SystemClipboard::Selection : SystemClipboard::Clipboard,
-                            SystemClipboard::ClipboardUpdateReason::PreventEmptyClipboard);
-    }
-}
-
 void Klipper::slotPopupMenu()
 {
     m_popup->show();
@@ -383,7 +345,7 @@ void Klipper::slotPopupMenu()
 
 void Klipper::slotRepeatAction()
 {
-    auto top = std::static_pointer_cast<const HistoryStringItem>(m_historyModel->first());
+    auto top = std::static_pointer_cast<const HistoryItem>(m_historyModel->first());
     if (top) {
         m_myURLGrabber->invokeAction(top);
     }
@@ -406,72 +368,13 @@ void Klipper::setURLGrabberEnabled(bool enable)
 
 void Klipper::slotHistoryChanged(bool isTop)
 {
-    if (!isTop || m_clip->isLocked(QClipboard::Selection) || m_clip->isLocked(QClipboard::Clipboard)) {
-        return;
-    }
-    if (m_bReplayActionInHistory && m_bURLGrabber) {
-        slotRepeatAction();
-    }
-}
-
-HistoryItemPtr Klipper::applyClipChanges(const QMimeData *clipData)
-{
-    Q_ASSERT(m_clip->isLocked(QClipboard::Selection) || m_clip->isLocked(QClipboard::Clipboard));
-    if (m_historyModel->rowCount() > 0) {
-        if (m_bIgnoreImages && m_historyModel->first()->type() == HistoryItemType::Image) {
-            m_historyModel->remove(m_historyModel->first()->uuid());
-        }
-    }
-
-    HistoryItemPtr item = HistoryItem::create(clipData);
-
-    bool saveToHistory = true;
-    if (clipData->data(QStringLiteral("x-kde-passwordManagerHint")) == QByteArrayLiteral("secret")) {
-        saveToHistory = false;
-    }
-    if (saveToHistory && item) {
-        m_historyModel->insert(item);
-    }
-
-    return item;
-}
-
-void Klipper::checkClipData(QClipboard::Mode mode, const QMimeData *data)
-{
-    Q_ASSERT(m_clip->isLocked(QClipboard::Selection) || m_clip->isLocked(QClipboard::Clipboard));
-    bool changed = true; // ### FIXME (only relevant under polling, might be better to simply remove polling and rely on XFixes)
-
-    // this must be below the "bNoNullClipboard" handling code!
-    // XXX: I want a better handling of selection/clipboard in general.
-    // XXX: Order sensitive code. Must die.
-    const bool selectionMode = mode == QClipboard::Selection;
-    if (selectionMode && m_bIgnoreSelection) {
-        if (m_bSynchronize) {
-            auto item = HistoryItem::create(data);
-            if (item) [[likely]] { // applyClipChanges can return nullptr
-                m_clip->setMimeData(item, SystemClipboard::Clipboard, SystemClipboard::ClipboardUpdateReason::SyncSelection);
-            }
-        }
+    if (!isTop) {
         return;
     }
 
-    if (selectionMode && m_bSelectionTextOnly && !data->hasText())
-        return;
-
-    if (m_bIgnoreImages && data->hasImage() && !data->hasText() /*BUG 491488*/ && !data->hasFormat(QStringLiteral("x-kde-force-image-copy"))) {
-        return;
-    }
-
-    HistoryItemPtr item = applyClipChanges(data);
-    if (changed) {
-        qCDebug(KLIPPER_LOG) << "Synchronize?" << m_bSynchronize;
-        if (m_bSynchronize && item) { // applyClipChanges can return nullptr
-            m_clip->setMimeData(item, mode == QClipboard::Selection ? SystemClipboard::Clipboard : SystemClipboard::Selection);
-        }
-    }
-    QString &lastURLGrabberText = selectionMode ? m_lastURLGrabberTextSelection : m_lastURLGrabberTextClipboard;
-    if (m_bURLGrabber && item && data->hasText()) {
-        m_myURLGrabber->checkNewData(std::const_pointer_cast<const HistoryItem>(item));
+    QString &lastURLGrabberText = m_clip->isLocked(QClipboard::Selection) ? m_lastURLGrabberTextSelection : m_lastURLGrabberTextClipboard;
+    if (auto item = m_historyModel->first(); m_bURLGrabber && item && item->type() == HistoryItemType::Text) {
+        m_myURLGrabber->checkNewData(std::const_pointer_cast<const HistoryItem>(m_historyModel->first()));
 
         // Make sure URLGrabber doesn't repeat all the time if klipper reads the same
         // text all the time (e.g. because XFixes is not available and the application
@@ -483,6 +386,13 @@ void Klipper::checkClipData(QClipboard::Mode mode, const QMimeData *data)
     } else {
         lastURLGrabberText.clear();
     }
+
+    if (m_clip->isLocked(QClipboard::Selection) || m_clip->isLocked(QClipboard::Clipboard)) {
+        return;
+    }
+    if (m_bReplayActionInHistory && m_bURLGrabber) {
+        slotRepeatAction();
+    }
 }
 
 QStringList Klipper::getClipboardHistoryMenu()
@@ -500,24 +410,6 @@ QString Klipper::getClipboardHistoryItem(int i)
     return m_historyModel->index(i).data(Qt::DisplayRole).toString();
 }
 
-//
-// changing a spinbox in klipper's config-dialog causes the lineedit-contents
-// of the spinbox to be selected and hence the clipboard changes. But we don't
-// want all those items in klipper's history. See #41917
-//
-bool Klipper::ignoreClipboardChanges() const
-{
-    QWidget *focusWidget = qApp->focusWidget();
-    if (focusWidget) {
-        if (focusWidget->inherits("QSpinBox")
-            || (focusWidget->parentWidget() && focusWidget->inherits("QLineEdit") && focusWidget->parentWidget()->inherits("QSpinWidget"))) {
-            return true;
-        }
-    }
-
-    return false;
-}
-
 void Klipper::updateTimestamp()
 {
 #if HAVE_X11
@@ -644,3 +536,5 @@ QString Klipper::cycleText() const
     result += QLatin1String("</table>");
     return result;
 }
+
+#include "moc_klipper.cpp"
