@@ -10,6 +10,7 @@
 #include "config-klipper.h"
 
 #include <QClipboard>
+#include <QDBusContext>
 #include <QElapsedTimer>
 #include <QPointer>
 
@@ -22,7 +23,6 @@ class KToggleAction;
 class KActionCollection;
 class KlipperPopup;
 class HistoryCycler;
-class QTime;
 class QAction;
 class QMenu;
 class QMimeData;
@@ -39,7 +39,7 @@ class PlasmaShell;
 }
 }
 
-class KLIPPER_EXPORT Klipper : public QObject
+class KLIPPER_EXPORT Klipper : public QObject, public QDBusContext
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.klipper.klipper")
@@ -55,9 +55,15 @@ public Q_SLOTS:
     Q_SCRIPTABLE void showKlipperPopupMenu();
     Q_SCRIPTABLE void showKlipperManuallyInvokeActionMenu();
 
+    /*
+     * Reloads the current configuration
+     * @since 6.3
+     */
+    Q_SCRIPTABLE void reloadConfig();
+
 public:
     static std::shared_ptr<Klipper> self();
-    Klipper(QObject *parent, const KSharedConfigPtr &config);
+    Klipper(QObject *parent = nullptr);
     ~Klipper() override;
 
     bool eventFilter(QObject *object, QEvent *event) override;
@@ -87,34 +93,12 @@ public Q_SLOTS:
     void slotCycleNext();
     void slotCyclePrev();
 
-protected:
-    /**
-     * Check data in clipboard, and if it passes these checks,
-     * store the data in the clipboard history.
-     */
-    void checkClipData(QClipboard::Mode mode, const QMimeData *data);
-
-    /**
-     * Enter clipboard data in the history.
-     */
-    [[nodiscard]] std::shared_ptr<HistoryItem> applyClipChanges(const QMimeData *data);
-
-    bool ignoreClipboardChanges() const;
-
-    KSharedConfigPtr config() const
-    {
-        return m_config;
-    }
-
 Q_SIGNALS:
     void passivePopup(const QString &caption, const QString &text);
     void editFinished(std::shared_ptr<const HistoryItem> item, int result);
     Q_SCRIPTABLE void clipboardHistoryUpdated();
 
 public Q_SLOTS:
-    void slotIgnored(QClipboard::Mode mode);
-    void slotReceivedEmptyClipboard(QClipboard::Mode mode);
-
     void slotPopupMenu();
     void setURLGrabberEnabled(bool);
 
@@ -131,7 +115,6 @@ private Q_SLOTS:
     void loadSettings();
 
 private:
-    explicit Klipper(const KSharedConfigPtr &config);
     static void updateTimestamp();
 
     std::shared_ptr<SystemClipboard> m_clip;
@@ -156,16 +139,10 @@ private:
     bool m_bURLGrabber : 1;
     bool m_bReplayActionInHistory : 1;
     bool m_bUseGUIRegExpEditor : 1;
-    bool m_bNoNullClipboard : 1;
-    bool m_bIgnoreSelection : 1;
-    bool m_bSynchronize : 1;
-    bool m_bSelectionTextOnly : 1;
-    bool m_bIgnoreImages : 1;
 
     URLGrabber *m_myURLGrabber;
     QString m_lastURLGrabberTextSelection;
     QString m_lastURLGrabberTextClipboard;
-    KSharedConfigPtr m_config;
 
     QString cycleText() const;
     KActionCollection *m_collection;
