@@ -61,37 +61,6 @@ void sanity_check(int argc, char *argv[])
 {
     QString msg;
     QByteArray path = qgetenv("HOME");
-    const QByteArray readOnly = qgetenv("KDE_HOME_READONLY");
-    if (path.isEmpty()) {
-        msg = i18n("$HOME not set!");
-    }
-    if (msg.isEmpty() && access(path.data(), W_OK)) {
-        if (errno == ENOENT) {
-            msg = i18n("$HOME directory (%1) does not exist.", QFile::decodeName(path));
-        } else if (readOnly.isEmpty()) {
-            msg = xi18nc("@info",
-                         "No write access to $HOME directory (%1). If this is intentional, set <envar>KDE_HOME_READONLY=1</envar> in your environment.",
-                         QFile::decodeName(path));
-        }
-    }
-    if (msg.isEmpty() && access(path.data(), R_OK)) {
-        if (errno == ENOENT) {
-            msg = i18n("$HOME directory (%1) does not exist.", QFile::decodeName(path));
-        } else {
-            msg = i18n("No read access to $HOME directory (%1).", QFile::decodeName(path));
-        }
-    }
-    if (msg.isEmpty() && readOnly.isEmpty() && !writeTest(path)) {
-        if (errno == ENOSPC) {
-            msg = i18n("$HOME directory (%1) is out of disk space.", QFile::decodeName(path));
-        } else {
-            msg = i18n(
-                "Writing to the $HOME directory (%2) failed with "
-                "the error '%1'",
-                QString::fromLocal8Bit(strerror(errno)),
-                QFile::decodeName(path));
-        }
-    }
     if (msg.isEmpty()) {
         path = getenv("ICEAUTHORITY");
         if (path.isEmpty()) {
@@ -105,37 +74,6 @@ void sanity_check(int argc, char *argv[])
             msg = i18n("No read access to '%1'.", QFile::decodeName(path));
         }
     }
-    if (msg.isEmpty()) {
-        path = getenv("KDETMP");
-        if (path.isEmpty()) {
-            path = "/tmp";
-        }
-        if (!writeTest(path)) {
-            if (errno == ENOSPC) {
-                msg = i18n("Temp directory (%1) is out of disk space.", QFile::decodeName(path));
-            } else {
-                msg = i18n(
-                    "Writing to the temp directory (%2) failed with\n    "
-                    "the error '%1'",
-                    QString::fromLocal8Bit(strerror(errno)),
-                    QFile::decodeName(path));
-            }
-        }
-    }
-    if (msg.isEmpty() && (path != "/tmp")) {
-        path = "/tmp";
-        if (!writeTest(path)) {
-            if (errno == ENOSPC) {
-                msg = i18n("Temp directory (%1) is out of disk space.", QFile::decodeName(path));
-            } else {
-                msg = i18n(
-                    "Writing to the temp directory (%2) failed with\n    "
-                    "the error '%1'",
-                    QString::fromLocal8Bit(strerror(errno)),
-                    QFile::decodeName(path));
-            }
-        }
-    }
     if (msg.isEmpty()) {
         path += "/.ICE-unix";
         if (access(path.data(), W_OK) && (errno != ENOENT)) {
@@ -154,9 +92,6 @@ void sanity_check(int argc, char *argv[])
         fprintf(stderr, "%s", msg.toUtf8().constData());
         fputs(msg_post.toUtf8().constData(), stderr);
 
-        QApplication a(argc, argv);
-        const QString qmsg = msg_pre + msg + msg_post;
-        KMessageBox::error(nullptr, qmsg, i18n("Plasma Workspace installation problem!"));
         exit(255);
     }
 }
@@ -169,7 +104,7 @@ int main(int argc, char *argv[])
 
     // force xcb QPA plugin as ksmserver is very X11 specific
     const QByteArray origQpaPlatform = qgetenv("QT_QPA_PLATFORM");
-    qputenv("QT_QPA_PLATFORM", QByteArrayLiteral("xcb"));
+    qputenv("QT_QPA_PLATFORM", QByteArrayView("xcb"));
 
     QCoreApplication::setQuitLockEnabled(false);
     auto a = new QGuiApplication(argc, argv);
