@@ -40,7 +40,7 @@ public:
 
     QStringList behaviorMatchesList(const KConfigGroup &group, Settings::NotificationBehavior behavior, bool on) const;
 
-    Settings *q;
+    Settings *const q;
 
     KSharedConfig::Ptr config;
 
@@ -596,3 +596,5 @@ void Settings::setNotificationSoundsInhibited(bool inhibited)
     d->dndSettings.setNotificationSoundsMuted(inhibited);
     d->setDirty(true);
 }
+
+#include "moc_settings.cpp"
