@@ -9,12 +9,18 @@
 #include <QQmlParserStatus>
 #include <QSortFilterProxyModel>
 
+#include <memory>
+
 #include "abstracttasksmodeliface.h"
+#include "regionfiltermode.h"
 
 #include "taskmanager_export.h"
 
 namespace TaskManager
 {
+class ActivityInfo;
+class VirtualDesktopInfo;
+
 /**
  * @short A unified tasks model.
  *
@@ -41,6 +47,7 @@ namespace TaskManager
 class TASKMANAGER_EXPORT TasksModel : public QSortFilterProxyModel, public AbstractTasksModelIface, public QQmlParserStatus
 {
     Q_OBJECT
+    QML_ELEMENT
     Q_INTERFACES(QQmlParserStatus)
 
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
@@ -52,11 +59,13 @@ class TASKMANAGER_EXPORT TasksModel : public QSortFilterProxyModel, public Abstr
 
     Q_PROPERTY(QVariant virtualDesktop READ virtualDesktop WRITE setVirtualDesktop NOTIFY virtualDesktopChanged)
     Q_PROPERTY(QRect screenGeometry READ screenGeometry WRITE setScreenGeometry NOTIFY screenGeometryChanged)
+    Q_PROPERTY(QRect regionGeometry READ regionGeometry WRITE setRegionGeometry NOTIFY regionGeometryChanged)
     Q_PROPERTY(QString activity READ activity WRITE setActivity NOTIFY activityChanged)
 
     Q_PROPERTY(bool filterByVirtualDesktop READ filterByVirtualDesktop WRITE setFilterByVirtualDesktop NOTIFY filterByVirtualDesktopChanged)
     Q_PROPERTY(bool filterByScreen READ filterByScreen WRITE setFilterByScreen NOTIFY filterByScreenChanged)
     Q_PROPERTY(bool filterByActivity READ filterByActivity WRITE setFilterByActivity NOTIFY filterByActivityChanged)
+    Q_PROPERTY(RegionFilterMode::Mode filterByRegion READ filterByRegion WRITE setFilterByRegion NOTIFY filterByRegionChanged)
     Q_PROPERTY(bool filterMinimized READ filterMinimized WRITE setFilterMinimized NOTIFY filterMinimizedChanged)
     Q_PROPERTY(bool filterNotMinimized READ filterNotMinimized WRITE setFilterNotMinimized NOTIFY filterNotMinimizedChanged)
     Q_PROPERTY(bool filterNotMaximized READ filterNotMaximized WRITE setFilterNotMaximized NOTIFY filterNotMaximizedChanged)
@@ -65,6 +74,7 @@ class TASKMANAGER_EXPORT TasksModel : public QSortFilterProxyModel, public Abstr
     Q_PROPERTY(SortMode sortMode READ sortMode WRITE setSortMode NOTIFY sortModeChanged)
     Q_PROPERTY(bool separateLaunchers READ separateLaunchers WRITE setSeparateLaunchers NOTIFY separateLaunchersChanged)
     Q_PROPERTY(bool launchInPlace READ launchInPlace WRITE setLaunchInPlace NOTIFY launchInPlaceChanged)
+    Q_PROPERTY(bool hideActivatedLaunchers READ hideActivatedLaunchers WRITE setHideActivatedLaunchers NOTIFY hideActivatedLaunchersChanged)
 
     Q_PROPERTY(GroupMode groupMode READ groupMode WRITE setGroupMode NOTIFY groupModeChanged)
     Q_PROPERTY(bool groupInline READ groupInline WRITE setGroupInline NOTIFY groupInlineChanged)
@@ -177,6 +187,27 @@ public:
      **/
     void setScreenGeometry(const QRect &geometry);
 
+    /**
+     * The geometry of the region used in filtering by region. Defaults
+     * to a null QRect.
+     *
+     * @see setRegionGeometry
+     * @since 6.0
+     * @returns the geometry of the region used in filtering.
+     **/
+    QRect regionGeometry() const;
+
+    /**
+     * Set the geometry of the screen to use in filtering by region.
+     *
+     * If set to an invalid QRect, filtering by region is disabled.
+     *
+     * @see regionGeometry
+     * @since 6.0
+     * @param geometry A region geometry.
+     **/
+    void setRegionGeometry(const QRect &geometry);
+
     /**
      * The id of the activity used in filtering by activity. Usually
      * set to the id of the current activity. Defaults to an empty id.
@@ -268,6 +299,35 @@ public:
      **/
     void setFilterByActivity(bool filter);
 
+    /**
+     * Whether tasks should be filtered by region. Defaults to @c RegionFilterMode::Disabled.
+     *
+     * Filtering by region only happens if a region is set, even
+     * if the filter is enabled.
+     *
+     * @see RegionFilterMode
+     * @see setFilterByRegion
+     * @see setRegionGeometry
+     * @since 6.0
+     * @returns Region filter mode.
+     **/
+    RegionFilterMode::Mode filterByRegion() const;
+
+    /**
+     * Set whether tasks should be filtered by region. Defaults to
+     * @c RegionFilterMode::Disabled.
+     *
+     * Filtering by region only happens if a region is set,
+     * even if the filter is enabled.
+     *
+     * @see RegionFilterMode
+     * @see filterByRegion
+     * @see setRegionGeometry
+     * @since 6.0
+     * @param mode Region filter mode.
+     **/
+    void setFilterByRegion(RegionFilterMode::Mode mode);
+
     /**
      * Whether minimized tasks should be filtered out. Defaults to
      * @c false.
@@ -419,6 +479,26 @@ public:
      **/
     void setLaunchInPlace(bool launchInPlace);
 
+    /**
+     * Whether launchers should be hidden after they have been
+     * activated. Defaults to @c true.
+     *
+     * @see hideActivatedLaunchers
+     * @returns whether launchers will be hidden after they have been
+     * activated.
+     **/
+    bool hideActivatedLaunchers() const;
+
+    /**
+     * Sets whether launchers should be hidden after they have been
+     * activated. Defaults to @c true.
+     *
+     * @see hideActivatedLaunchers
+     * @param hideActivatedLaunchers Whether launchers should be hidden
+     * after they have been activated.
+     **/
+    void setHideActivatedLaunchers(bool hideActivatedLaunchers);
+
     /**
      * Returns the current group mode, i.e. the criteria by which tasks should
      * be grouped.
@@ -900,10 +980,12 @@ Q_SIGNALS:
     void anyTaskDemandsAttentionChanged() const;
     void virtualDesktopChanged() const;
     void screenGeometryChanged() const;
+    void regionGeometryChanged();
     void activityChanged() const;
     void filterByVirtualDesktopChanged() const;
     void filterByScreenChanged() const;
     void filterByActivityChanged() const;
+    void filterByRegionChanged();
     void filterMinimizedChanged();
     void filterNotMinimizedChanged() const;
     void filterNotMaximizedChanged() const;
@@ -911,6 +993,7 @@ Q_SIGNALS:
     void sortModeChanged() const;
     void separateLaunchersChanged() const;
     void launchInPlaceChanged() const;
+    void hideActivatedLaunchersChanged() const;
     void groupModeChanged() const;
     void groupInlineChanged() const;
     void groupingWindowTasksThresholdChanged() const;
@@ -923,13 +1006,23 @@ protected:
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
     bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
 
+    /**
+     * @return a shared pointer to VirtualDesktopInfo to access virtual desktop information
+     */
+    std::shared_ptr<VirtualDesktopInfo> virtualDesktopInfo() const;
+
+    /**
+     * @return a shared pointer to ActivityInfo to access activity information
+     */
+    std::shared_ptr<ActivityInfo> activityInfo() const;
+
 private:
     Q_INVOKABLE void updateLauncherCount();
 
     class Private;
     class TasksModelLessThan;
     friend class TasksModelLessThan;
-    QScopedPointer<Private> d;
+    std::unique_ptr<Private> d;
 };
 
 }
