@@ -353,6 +353,10 @@ public:
             }
         });
         initialize();
+        if (!isActive()) {
+            qCWarning(TASKMANAGER_DEBUG)
+                << "The PlasmaWindowManagement protocol hasn't activated in time. The client possibly got denied by kwin? Check kwin output.";
+        }
     }
     ~PlasmaWindowManagement()
     {
@@ -443,7 +447,7 @@ public:
     void dataChanged(PlasmaWindow *window, const QList<int> &roles);
 
 private:
-    WaylandTasksModel *q;
+    WaylandTasksModel *const q;
 };
 
 QUuid WaylandTasksModel::Private::uuid = QUuid::createUuid();
@@ -561,7 +565,7 @@ void WaylandTasksModel::Private::addWindow(PlasmaWindow *window)
             if (transients.remove(window)) {
                 if (PlasmaWindow *leader = transientsDemandingAttention.key(window)) {
                     transientsDemandingAttention.remove(leader, window);
-                    dataChanged(leader, QVector<int>{IsDemandingAttention});
+                    dataChanged(leader, QList<int>{IsDemandingAttention});
                 }
             }
         }
@@ -641,8 +645,8 @@ void WaylandTasksModel::Private::addWindow(PlasmaWindow *window)
                 if (window->parentWindow != oldLeader) {
                     transientsDemandingAttention.remove(oldLeader, window);
                     transientsDemandingAttention.insert(leader, window);
-                    dataChanged(oldLeader, QVector<int>{IsDemandingAttention});
-                    dataChanged(leader, QVector<int>{IsDemandingAttention});
+                    dataChanged(oldLeader, QList<int>{IsDemandingAttention});
+                    dataChanged(leader, QList<int>{IsDemandingAttention});
                 }
             }
         }
@@ -716,7 +720,7 @@ void WaylandTasksModel::Private::addWindow(PlasmaWindow *window)
 
         // If the count has changed from 0, the window may no longer be on all virtual
         // desktops.
-        if (window->virtualDesktops.count() > 0) {
+        if (!window->virtualDesktops.isEmpty()) {
             this->dataChanged(window, IsOnAllVirtualDesktops);
         }
     });
@@ -725,7 +729,7 @@ void WaylandTasksModel::Private::addWindow(PlasmaWindow *window)
         this->dataChanged(window, VirtualDesktops);
 
         // If the count has changed to 0, the window is now on all virtual desktops.
-        if (window->virtualDesktops.count() == 0) {
+        if (window->virtualDesktops.isEmpty()) {
             this->dataChanged(window, IsOnAllVirtualDesktops);
         }
     });
@@ -740,13 +744,13 @@ void WaylandTasksModel::Private::addWindow(PlasmaWindow *window)
             if (window->windowState.testFlag(PlasmaWindow::state::state_demands_attention)) {
                 if (!transientsDemandingAttention.values(leader).contains(window)) {
                     transientsDemandingAttention.insert(leader, window);
-                    this->dataChanged(leader, QVector<int>{IsDemandingAttention});
+                    this->dataChanged(leader, QList<int>{IsDemandingAttention});
                 }
             } else if (transientsDemandingAttention.remove(leader, window)) {
-                this->dataChanged(leader, QVector<int>{IsDemandingAttention});
+                this->dataChanged(leader, QList<int>{IsDemandingAttention});
             }
         } else {
-            this->dataChanged(window, QVector<int>{IsDemandingAttention});
+            this->dataChanged(window, QList<int>{IsDemandingAttention});
         }
     });
 
@@ -769,7 +773,7 @@ void WaylandTasksModel::Private::addWindow(PlasmaWindow *window)
         // Update demands attention state for leader.
         if (window->windowState.testFlag(PlasmaWindow::state::state_demands_attention)) {
             transientsDemandingAttention.insert(leader, window);
-            dataChanged(leader, QVector<int>{IsDemandingAttention});
+            dataChanged(leader, QList<int>{IsDemandingAttention});
         }
     }
 
@@ -1296,3 +1300,5 @@ QList<QUuid> WaylandTasksModel::winIdsFromMimeData(const QMimeData *mimeData, bo
 }
 
 #include "waylandtasksmodel.moc"
+
+#include "moc_waylandtasksmodel.cpp"
