@@ -23,7 +23,6 @@
 
 class AutoHideScreenEdge;
 class ShellCorona;
-class PanelConfigView;
 
 namespace LayerShellQt
 {
@@ -236,6 +235,8 @@ public:
 
     Q_INVOKABLE void fixUnsupportedConfiguration();
 
+    Q_INVOKABLE void clonePanelTo(Plasma::Types::Location location, QScreen *screen);
+
     /* Both Shared with script/panel.cpp */
     static KConfigGroup panelConfig(ShellCorona *corona, Plasma::Containment *containment, QScreen *screen);
     static KConfigGroup panelConfigDefaults(ShellCorona *corona, Plasma::Containment *containment, QScreen *screen);
@@ -249,6 +250,7 @@ public:
     QScreen *screenToFollow() const;
 
     bool isUserConfiguring() const;
+    void restore();
 
 protected:
     QSize preferredSize() const;
@@ -291,7 +293,6 @@ protected Q_SLOTS:
     void showConfigurationInterface(Plasma::Applet *applet) override;
 
 private Q_SLOTS:
-    void restore();
     void setAutoHideEnabled(bool autoHideEnabled);
     void showTemporarily();
     void refreshContainment();
