@@ -10,8 +10,8 @@
 #include <QFile>
 #include <QImageReader>
 
-#include "config-KF5KExiv2.h"
-#if HAVE_KF5KExiv2
+#include "config-KExiv2.h"
+#if HAVE_KExiv2
 #include <KExiv2/KExiv2>
 #endif
 
@@ -28,67 +28,43 @@ void MediaMetadataFinder::run()
     const QImageReader reader(m_path);
     metadata.resolution = reader.size();
 
-#if HAVE_KF5KExiv2
+#if HAVE_KExiv2
     KExiv2Iface::KExiv2 exivImage(m_path);
 
     // Extract title from XPTitle
     {
         const QByteArray titleByte = exivImage.getExifTagData("Exif.Image.XPTitle");
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        metadata.title = QString::fromUtf8(titleByte);
-#else
         metadata.title = QString::fromUtf8(titleByte).chopped(std::min<qsizetype>(titleByte.size(), 1));
-#endif
     }
 
     // Use documentName as title
     if (metadata.title.isEmpty()) {
         const QByteArray titleByte = exivImage.getExifTagData("Exif.Image.DocumentName");
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        metadata.title = QString::fromUtf8(titleByte);
-#else
         metadata.title = QString::fromUtf8(titleByte).chopped(std::min<qsizetype>(titleByte.size(), 1));
-#endif
     }
 
     // Use description as title
     if (metadata.title.isEmpty()) {
         const QByteArray titleByte = exivImage.getExifTagData("Exif.Image.ImageDescription");
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        metadata.title = QString::fromUtf8(titleByte);
-#else
         metadata.title = QString::fromUtf8(titleByte).chopped(std::min<qsizetype>(titleByte.size(), 1));
-#endif
     }
 
     // Extract author from artist
     {
         const QByteArray authorByte = exivImage.getExifTagData("Exif.Image.Artist");
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        metadata.author = QString::fromUtf8(authorByte);
-#else
         metadata.author = QString::fromUtf8(authorByte).chopped(std::min<qsizetype>(authorByte.size(), 1));
-#endif
     }
 
     // Extract author from XPAuthor
     if (metadata.author.isEmpty()) {
         const QByteArray authorByte = exivImage.getExifTagData("Exif.Image.XPAuthor");
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        metadata.author = QString::fromUtf8(authorByte);
-#else
         metadata.author = QString::fromUtf8(authorByte).chopped(std::min<qsizetype>(authorByte.size(), 1));
-#endif
     }
 
     // Extract author from copyright
     if (metadata.author.isEmpty()) {
         const QByteArray authorByte = exivImage.getExifTagData("Exif.Image.Copyright");
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        metadata.author = QString::fromUtf8(authorByte);
-#else
         metadata.author = QString::fromUtf8(authorByte).chopped(std::min<qsizetype>(authorByte.size(), 1));
-#endif
     }
 #endif
 
